@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
+ *    trademarks of the OX Software GmbH. group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016-2020 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,17 +52,14 @@ package com.openexchange.mailfilter.json.ajax.json.mapper.parser.test;
 import java.util.ArrayList;
 import java.util.List;
 import org.apache.jsieve.SieveException;
-import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.jsieve.commands.TestCommand;
 import com.openexchange.jsieve.commands.TestCommand.Commands;
-import com.openexchange.mailfilter.json.ajax.json.fields.AddressEnvelopeAndHeaderTestField;
 import com.openexchange.mailfilter.json.ajax.json.fields.GeneralField;
 import com.openexchange.mailfilter.json.ajax.json.fields.NotTestField;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.CommandParser;
-import com.openexchange.mailfilter.json.ajax.json.mapper.parser.CommandParserJSONUtil;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.CommandParserRegistry;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.TestCommandParserRegistry;
 import com.openexchange.mailfilter.json.osgi.Services;
@@ -83,20 +80,31 @@ public class NotTestCommandParser implements CommandParser<TestCommand> {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.mapper.parser.CommandParser#parse(org.json.JSONObject)
      */
     @Override
     public TestCommand parse(JSONObject jsonObject) throws JSONException, SieveException, OXException {
+        // FIXME Not parser seems to be broken by design
+
+
         final List<Object> argList = new ArrayList<Object>();
-        final JSONArray valuesArray = jsonObject.getJSONArray(AddressEnvelopeAndHeaderTestField.values.name());
-        argList.add(CommandParserJSONUtil.coerceToStringList(valuesArray));
-        return new TestCommand(TestCommand.Commands.NOT, argList, new ArrayList<TestCommand>());
+        ArrayList<TestCommand> testcommands = new ArrayList<TestCommand>();
+
+        final JSONObject innerJsonObject = jsonObject.optJSONObject(NotTestField.test.name());
+        if (null != innerJsonObject) {
+            CommandParserRegistry<TestCommand> parserRegistry = Services.getService(TestCommandParserRegistry.class);
+            CommandParser<TestCommand> parser = parserRegistry.get(innerJsonObject.optString(GeneralField.id.name()));
+            if (null != parser) {
+                testcommands.add(parser.parse(innerJsonObject));
+            }
+        }
+        return new TestCommand(TestCommand.Commands.NOT, argList, testcommands);
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.mailfilter.json.ajax.json.mapper.parser.CommandParser#parse(org.json.JSONObject, java.lang.Object)
      */
     @Override
@@ -107,7 +115,9 @@ public class NotTestCommandParser implements CommandParser<TestCommand> {
         TestCommand nestedTestCommand = command.getTestCommands().get(0);
         CommandParserRegistry<TestCommand> parserRegistry = Services.getService(TestCommandParserRegistry.class);
         CommandParser<TestCommand> parser = parserRegistry.get(nestedTestCommand.getCommand().getCommandName());
-        parser.parse(testobject, nestedTestCommand);
+        if (null != parser) {
+            parser.parse(testobject, nestedTestCommand);
+        }
 
         jsonObject.put(NotTestField.test.name(), testobject);
     }
