@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
+ *    trademarks of the OX Software GmbH. group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -59,6 +59,7 @@ import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.jsieve.commands.TestCommand.Commands;
+import com.openexchange.jsieve.registry.TestCommandRegistry;
 import com.openexchange.mailfilter.MailFilterService;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.TestCommandParserRegistry;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.AddressTestCommandParser;
@@ -67,6 +68,7 @@ import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.AnyOfTestCo
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.BodyTestCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.CurrentDateTestCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.EnvelopeTestCommandParser;
+import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.HasFlagCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.HeaderTestCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.NotTestCommandParser;
 import com.openexchange.mailfilter.json.ajax.json.mapper.parser.test.SizeTestCommandParser;
@@ -92,7 +94,7 @@ public class MailFilterJSONActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, MailFilterService.class, HttpService.class, SessiondService.class, DispatcherPrefixService.class, CapabilityService.class };
+        return new Class<?>[] { ConfigurationService.class, MailFilterService.class, HttpService.class, SessiondService.class, DispatcherPrefixService.class, CapabilityService.class, TestCommandRegistry.class};
     }
 
     @Override
@@ -139,6 +141,7 @@ public class MailFilterJSONActivator extends HousekeepingActivator {
         registry.register(Commands.NOT.getCommandName(), new NotTestCommandParser());
         registry.register(Commands.SIZE.getCommandName(), new SizeTestCommandParser());
         registry.register(Commands.TRUE.getCommandName(), new TrueTestCommandParser());
+        registry.register(Commands.HASFLAG.getCommandName(), new HasFlagCommandParser());
 
         registerService(TestCommandParserRegistry.class, registry);
         trackService(TestCommandParserRegistry.class);
