@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
+ *    trademarks of the OX Software GmbH. group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -55,6 +55,7 @@ import java.util.Hashtable;
 import java.util.List;
 import org.apache.jsieve.SieveException;
 import org.apache.jsieve.TagArgument;
+import com.openexchange.jsieve.commands.test.ITestCommand;
 
 public class TestCommand extends Command {
     /*
@@ -135,10 +136,10 @@ public class TestCommand extends Command {
     // return false;
     // }
     // }
-    public enum Commands {
+    public enum Commands implements ITestCommand {
         ADDRESS("address", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardAddressMatchTypes(), standardJSONAddressMatchTypes(), null),
         ENVELOPE("envelope", 2, Integer.MAX_VALUE, standardAddressPart(), standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), "envelope"),
-        EXITS("exists", 1, 1, null, null, null, null, null),
+//        EXITS("exists", 1, 1, null, null, null, null, null),
         FALSE("false", 0, 0, null, null, null, null, null),
         TRUE("true", 0, 0, null, null, null, null, null),
         NOT("not", 0, 0, null, null, null, null, null),
@@ -148,7 +149,8 @@ public class TestCommand extends Command {
         ANYOF("anyof", 0, 0, null, null, null, null, null),
         BODY("body", 1, 1, standardBodyPart(), null, standardMatchTypes(), standardJSONMatchTypes(), "body"),
         //DATE("date", 3, null, null, date_match_types(), "date"),
-        CURRENTDATE("currentdate", 2, Integer.MAX_VALUE, null, null, dateMatchTypes(), dateJSONMatchTypes(), "date");
+        CURRENTDATE("currentdate", 2, Integer.MAX_VALUE, null, null, dateMatchTypes(), dateJSONMatchTypes(), "date"),
+        HASFLAG("hasflag", 1, Integer.MAX_VALUE, null, standardComparators(), standardMatchTypes(), standardJSONMatchTypes(), null);
 
         private static Hashtable<String, String> matchTypeSize() {
             final Hashtable<String, String> match_type_size = new Hashtable<String, String>(2);
@@ -184,6 +186,7 @@ public class TestCommand extends Command {
 
         private static Hashtable<String, String> standardAddressMatchTypes() {
             final Hashtable<String, String> standard_match_types = standardMatchTypes();
+            standard_match_types.putAll(standardAddressPart());
             standard_match_types.put(":user", "subaddress");
             standard_match_types.put(":detail", "subaddress");
             return standard_match_types;
@@ -191,8 +194,11 @@ public class TestCommand extends Command {
 
         private static List<String[]> standardJSONAddressMatchTypes() {
             final List<String[]> standard_match_types = Collections.synchronizedList(new ArrayList<String[]>(2));
-            standard_match_types.add(new String[]{"subaddress", "user"});
-            standard_match_types.add(new String[]{"subaddress", "detail"});
+            standard_match_types.add(new String[] { "subaddress", "user" });
+            standard_match_types.add(new String[] { "subaddress", "detail" });
+            standard_match_types.add(new String[] { "", "all" });
+            standard_match_types.add(new String[] { "", "domain" });
+            standard_match_types.add(new String[] { "", "localpart" });
             return standard_match_types;
         }
 
@@ -298,26 +304,32 @@ public class TestCommand extends Command {
             this.required = required;
         }
 
+        @Override
         public final int getNumberOfArguments() {
             return numberOfArguments;
         }
 
+        @Override
         public final int getMaxNumberOfArguments() {
             return maxNumberOfArguments;
         }
 
+        @Override
         public final String getCommandName() {
             return commandName;
         }
 
+        @Override
         public final Hashtable<String, String> getAddress() {
             return address;
         }
 
+        @Override
         public final Hashtable<String, String> getComparator() {
             return comparator;
         }
 
+        @Override
         public final String getRequired() {
             return required;
         }
@@ -342,6 +354,7 @@ public class TestCommand extends Command {
             this.required = required;
         }
 
+        @Override
         public final Hashtable<String, String> getMatchTypes() {
             return matchTypes;
         }
@@ -350,12 +363,13 @@ public class TestCommand extends Command {
             this.matchTypes = matchtypes;
         }
 
+        @Override
         public List<String[]> getJsonMatchTypes() {
             return jsonMatchTypes;
         }
     }
 
-    private Commands command;
+    private ITestCommand command;
 
     private final List<String> tagArguments;
 
@@ -376,7 +390,7 @@ public class TestCommand extends Command {
         this.tagArguments = new ArrayList<String>();
     }
 
-    public TestCommand(final Commands command, final List<Object> arguments, final List<TestCommand> testcommands) throws SieveException {
+    public TestCommand(final ITestCommand command, final List<Object> arguments, final List<TestCommand> testcommands) throws SieveException {
         this.command = command;
         this.tagArguments = new ArrayList<String>();
         this.arguments = arguments;
@@ -460,7 +474,7 @@ public class TestCommand extends Command {
         throw new SieveException("An error occured while search the comparator tag in the arguments");
     }
 
-    public final Commands getCommand() {
+    public final ITestCommand getCommand() {
         return command;
     }
 
@@ -507,6 +521,10 @@ public class TestCommand extends Command {
         return testCommands;
     }
 
+    public final void removeTestCommand(TestCommand command) {
+        this.testCommands.remove(command);
+    }
+
     @Override
     public String toString() {
         return this.getClass().getSimpleName() + ": " + this.command.getCommandName() + " : " + this.tagArguments + " : " + this.arguments + " : " + this.testCommands;
@@ -515,7 +533,7 @@ public class TestCommand extends Command {
     @Override
     public HashSet<String> getRequired() {
         final HashSet<String> retval = new HashSet<String>();
-        final String required = this.command.required;
+        final String required = this.command.getRequired();
         if (null != required) {
             retval.add(required);
         }
@@ -531,7 +549,7 @@ public class TestCommand extends Command {
             retval.addAll(command.getRequired());
         }
         for (final String text : this.tagArguments) {
-            final String string = this.command.matchTypes.get(text);
+            final String string = this.command.getMatchTypes().get(text);
             if (null != string && (0 != string.length())) {
                 retval.add(string);
             }
