@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
+ *    trademarks of the OX Software GmbH. group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -252,7 +252,7 @@ public final class SieveTextFilter {
         SieveTextFilter stf = new SieveTextFilter("skata");
         String r = "# Generated by OX Sieve Bundle on Tue Mar 01 15:30:09 CET 2016\n" + "require [ \"date\" , \"vacation\" , \"relational\" , \"imap4flags\", \"fileinto\" ] ;\n\n"
 
-        + "## Flag: vacation|UniqueId:3|Rulename: vacation notice" + "if allof ( currentdate :value \"ge\" \"date\" \"2016-03-02\" , currentdate :value \"le\" \"date\" \"2016-03-09\" )" + " {";
+            + "## Flag: vacation|UniqueId:3|Rulename: vacation notice" + "if allof ( currentdate :value \"ge\" \"date\" \"2016-03-02\" , currentdate :value \"le\" \"date\" \"2016-03-09\" )" + " {";
         stf.readRequire(r);
     }
 
@@ -374,9 +374,10 @@ public final class SieveTextFilter {
             }
             if (error) {
                 retval = new ClientRulesAndRequire(requires, flagged);
+            } else {
+                retval = new ClientRulesAndRequire(new HashSet<String>(), flagged);
             }
 
-            retval = new ClientRulesAndRequire(new HashSet<String>(), flagged);
         } else {
             for (final Rule rule : rules) {
                 final RequireCommand requireCommand = rule.getRequireCommand();
@@ -388,9 +389,10 @@ public final class SieveTextFilter {
             }
             if (error) {
                 retval = new ClientRulesAndRequire(requires, listOfRules);
+            } else {
+                retval = new ClientRulesAndRequire(new HashSet<String>(), listOfRules);
             }
 
-            retval = new ClientRulesAndRequire(new HashSet<String>(), listOfRules);
         }
         return retval;
     }
@@ -965,7 +967,7 @@ public final class SieveTextFilter {
 
     /**
      * Rewrites the require part of the sieve script, retaining the previous and the current require sets.
-     * 
+     *
      * @param writeback The writeback after the CRUD operation
      * @param oldScript The old script before the CRUD operation
      * @param sieveTextFilter The {@link SieveTextFilter}
@@ -999,7 +1001,7 @@ public final class SieveTextFilter {
 
     /**
      * Reads the require line from the specified script and returns it as a set with strings with '"' quotes
-     * 
+     *
      * @param sieveScript The sieve script to read the require line from
      * @return The set with the requires, or an empty set if no require line is present.
      */
@@ -1021,7 +1023,7 @@ public final class SieveTextFilter {
 
     /**
      * Assemble the require line
-     * 
+     *
      * @param require The require set
      * @return The require line as a string, or an empty string if the specified set is empty
      */
@@ -1044,7 +1046,7 @@ public final class SieveTextFilter {
 
     /**
      * Injects the specified require line to the specified split write back string array
-     * 
+     *
      * @param splitWriteBack The split write back string array
      * @param requireLine The require line
      * @return The new writeback
@@ -1058,7 +1060,7 @@ public final class SieveTextFilter {
             splitWriteBack[1] = requireLine;
             writeBack = splitWriteBack;
         } else {
-            // Or add. Create a new array with size equals to the previous array + 2, to accommodate the require line plus an empty line 
+            // Or add. Create a new array with size equals to the previous array + 2, to accommodate the require line plus an empty line
             writeBack = new String[splitWriteBack.length + 2];
             // The top comment line
             writeBack[0] = splitWriteBack[0];
@@ -1073,7 +1075,7 @@ public final class SieveTextFilter {
 
     /**
      * Re-assemble the 'writeback' script from the array
-     * 
+     *
      * @param writeback
      * @return
      */
